aboutsummaryrefslogtreecommitdiffstats
path: root/sdk/src/java/lineageos/hardware
diff options
context:
space:
mode:
authorSam Mortimer <sam@mortimer.me.uk>2017-09-18 19:44:11 -0700
committerSam Mortimer <sam@mortimer.me.uk>2017-10-06 09:40:24 -0700
commit542742b751c961881ff88322aec08c91f4185037 (patch)
treeeea4b42dd4ff4670933c1fb203673222780b6a17 /sdk/src/java/lineageos/hardware
parent5ede05bdca6e034d84ff77224e5ce8d6b8029ef6 (diff)
downloadlineage-sdk-542742b751c961881ff88322aec08c91f4185037.tar.gz
lineage-sdk-542742b751c961881ff88322aec08c91f4185037.tar.bz2
lineage-sdk-542742b751c961881ff88322aec08c91f4185037.zip
lineage-sdk: rebrand step 2: update file contents
Change-Id: I9881acc57cdc0aeea2b296aac12a8af932d30aea
Diffstat (limited to 'sdk/src/java/lineageos/hardware')
-rw-r--r--sdk/src/java/lineageos/hardware/DisplayMode.aidl2
-rw-r--r--sdk/src/java/lineageos/hardware/DisplayMode.java10
-rw-r--r--sdk/src/java/lineageos/hardware/HSIC.aidl2
-rw-r--r--sdk/src/java/lineageos/hardware/HSIC.java2
-rw-r--r--sdk/src/java/lineageos/hardware/ILineageHardwareService.aidl12
-rw-r--r--sdk/src/java/lineageos/hardware/ILiveDisplayService.aidl6
-rw-r--r--sdk/src/java/lineageos/hardware/IThermalListenerCallback.aidl2
-rw-r--r--sdk/src/java/lineageos/hardware/LineageHardwareManager.java56
-rw-r--r--sdk/src/java/lineageos/hardware/LiveDisplayConfig.aidl2
-rw-r--r--sdk/src/java/lineageos/hardware/LiveDisplayConfig.java22
-rw-r--r--sdk/src/java/lineageos/hardware/LiveDisplayManager.java14
-rw-r--r--sdk/src/java/lineageos/hardware/ThermalListenerCallback.java2
-rw-r--r--sdk/src/java/lineageos/hardware/TouchscreenGesture.aidl2
-rw-r--r--sdk/src/java/lineageos/hardware/TouchscreenGesture.java2
14 files changed, 68 insertions, 68 deletions
diff --git a/sdk/src/java/lineageos/hardware/DisplayMode.aidl b/sdk/src/java/lineageos/hardware/DisplayMode.aidl
index a4f9163a..5dbab072 100644
--- a/sdk/src/java/lineageos/hardware/DisplayMode.aidl
+++ b/sdk/src/java/lineageos/hardware/DisplayMode.aidl
@@ -14,6 +14,6 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
parcelable DisplayMode;
diff --git a/sdk/src/java/lineageos/hardware/DisplayMode.java b/sdk/src/java/lineageos/hardware/DisplayMode.java
index 77172b8e..1e0f8476 100644
--- a/sdk/src/java/lineageos/hardware/DisplayMode.java
+++ b/sdk/src/java/lineageos/hardware/DisplayMode.java
@@ -14,14 +14,14 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
import android.os.Parcel;
import android.os.Parcelable;
-import cyanogenmod.os.Build;
-import cyanogenmod.os.Concierge;
-import cyanogenmod.os.Concierge.ParcelInfo;
+import lineageos.os.Build;
+import lineageos.os.Concierge;
+import lineageos.os.Concierge.ParcelInfo;
/**
* Display Modes API
@@ -55,7 +55,7 @@ public class DisplayMode implements Parcelable {
int tmpId = -1;
String tmpName = null;
- if (parcelableVersion >= Build.CM_VERSION_CODES.BOYSENBERRY) {
+ if (parcelableVersion >= Build.LINEAGE_VERSION_CODES.BOYSENBERRY) {
tmpId = parcel.readInt();
if (parcel.readInt() != 0) {
tmpName = parcel.readString();
diff --git a/sdk/src/java/lineageos/hardware/HSIC.aidl b/sdk/src/java/lineageos/hardware/HSIC.aidl
index 1689ee6c..1313a634 100644
--- a/sdk/src/java/lineageos/hardware/HSIC.aidl
+++ b/sdk/src/java/lineageos/hardware/HSIC.aidl
@@ -14,6 +14,6 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
parcelable HSIC;
diff --git a/sdk/src/java/lineageos/hardware/HSIC.java b/sdk/src/java/lineageos/hardware/HSIC.java
index df6cb5f0..b5a9f250 100644
--- a/sdk/src/java/lineageos/hardware/HSIC.java
+++ b/sdk/src/java/lineageos/hardware/HSIC.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
import android.graphics.Color;
import android.os.Parcel;
diff --git a/sdk/src/java/lineageos/hardware/ILineageHardwareService.aidl b/sdk/src/java/lineageos/hardware/ILineageHardwareService.aidl
index f8ec46d2..22785acb 100644
--- a/sdk/src/java/lineageos/hardware/ILineageHardwareService.aidl
+++ b/sdk/src/java/lineageos/hardware/ILineageHardwareService.aidl
@@ -15,15 +15,15 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
-import cyanogenmod.hardware.DisplayMode;
-import cyanogenmod.hardware.HSIC;
-import cyanogenmod.hardware.IThermalListenerCallback;
-import cyanogenmod.hardware.TouchscreenGesture;
+import lineageos.hardware.DisplayMode;
+import lineageos.hardware.HSIC;
+import lineageos.hardware.IThermalListenerCallback;
+import lineageos.hardware.TouchscreenGesture;
/** @hide */
-interface ICMHardwareService {
+interface ILineageHardwareService {
int getSupportedFeatures();
boolean get(int feature);
diff --git a/sdk/src/java/lineageos/hardware/ILiveDisplayService.aidl b/sdk/src/java/lineageos/hardware/ILiveDisplayService.aidl
index 3c9c971e..a9a766d9 100644
--- a/sdk/src/java/lineageos/hardware/ILiveDisplayService.aidl
+++ b/sdk/src/java/lineageos/hardware/ILiveDisplayService.aidl
@@ -14,10 +14,10 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
-import cyanogenmod.hardware.HSIC;
-import cyanogenmod.hardware.LiveDisplayConfig;
+import lineageos.hardware.HSIC;
+import lineageos.hardware.LiveDisplayConfig;
/** @hide */
interface ILiveDisplayService {
diff --git a/sdk/src/java/lineageos/hardware/IThermalListenerCallback.aidl b/sdk/src/java/lineageos/hardware/IThermalListenerCallback.aidl
index 1a53af20..b2273a60 100644
--- a/sdk/src/java/lineageos/hardware/IThermalListenerCallback.aidl
+++ b/sdk/src/java/lineageos/hardware/IThermalListenerCallback.aidl
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
interface IThermalListenerCallback {
void onThermalChanged(int state);
diff --git a/sdk/src/java/lineageos/hardware/LiveDisplayConfig.aidl b/sdk/src/java/lineageos/hardware/LiveDisplayConfig.aidl
index 326e2983..eac48d48 100644
--- a/sdk/src/java/lineageos/hardware/LiveDisplayConfig.aidl
+++ b/sdk/src/java/lineageos/hardware/LiveDisplayConfig.aidl
@@ -14,6 +14,6 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
parcelable LiveDisplayConfig;
diff --git a/sdk/src/java/lineageos/hardware/LiveDisplayConfig.java b/sdk/src/java/lineageos/hardware/LiveDisplayConfig.java
index dae3db80..c9ac6cc3 100644
--- a/sdk/src/java/lineageos/hardware/LiveDisplayConfig.java
+++ b/sdk/src/java/lineageos/hardware/LiveDisplayConfig.java
@@ -13,14 +13,14 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
-import static cyanogenmod.hardware.LiveDisplayManager.FEATURE_COLOR_BALANCE;
-import static cyanogenmod.hardware.LiveDisplayManager.FEATURE_FIRST;
-import static cyanogenmod.hardware.LiveDisplayManager.FEATURE_LAST;
-import static cyanogenmod.hardware.LiveDisplayManager.MODE_FIRST;
-import static cyanogenmod.hardware.LiveDisplayManager.MODE_LAST;
-import static cyanogenmod.hardware.LiveDisplayManager.MODE_OFF;
+import static lineageos.hardware.LiveDisplayManager.FEATURE_COLOR_BALANCE;
+import static lineageos.hardware.LiveDisplayManager.FEATURE_FIRST;
+import static lineageos.hardware.LiveDisplayManager.FEATURE_LAST;
+import static lineageos.hardware.LiveDisplayManager.MODE_FIRST;
+import static lineageos.hardware.LiveDisplayManager.MODE_LAST;
+import static lineageos.hardware.LiveDisplayManager.MODE_OFF;
import android.os.Parcel;
import android.os.Parcelable;
@@ -30,9 +30,9 @@ import java.util.Arrays;
import java.util.BitSet;
import java.util.List;
-import cyanogenmod.os.Build;
-import cyanogenmod.os.Concierge;
-import cyanogenmod.os.Concierge.ParcelInfo;
+import lineageos.os.Build;
+import lineageos.os.Concierge;
+import lineageos.os.Concierge.ParcelInfo;
/**
* Holder class for LiveDisplay static configuration.
@@ -112,7 +112,7 @@ public class LiveDisplayConfig implements Parcelable {
int maxColorBalance = 0;
float[] paRanges = new float[10];
- if (parcelableVersion >= Build.CM_VERSION_CODES.FIG) {
+ if (parcelableVersion >= Build.LINEAGE_VERSION_CODES.FIG) {
capabilities = parcel.readLong();
defaultMode = parcel.readInt();
defaultDayTemperature = parcel.readInt();
diff --git a/sdk/src/java/lineageos/hardware/ThermalListenerCallback.java b/sdk/src/java/lineageos/hardware/ThermalListenerCallback.java
index 3ef312d0..8d1aefba 100644
--- a/sdk/src/java/lineageos/hardware/ThermalListenerCallback.java
+++ b/sdk/src/java/lineageos/hardware/ThermalListenerCallback.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
/**
* Callback class to register for thermal state changes
diff --git a/sdk/src/java/lineageos/hardware/TouchscreenGesture.aidl b/sdk/src/java/lineageos/hardware/TouchscreenGesture.aidl
index f9a7a7b4..b968673b 100644
--- a/sdk/src/java/lineageos/hardware/TouchscreenGesture.aidl
+++ b/sdk/src/java/lineageos/hardware/TouchscreenGesture.aidl
@@ -15,6 +15,6 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
parcelable TouchscreenGesture;
diff --git a/sdk/src/java/lineageos/hardware/TouchscreenGesture.java b/sdk/src/java/lineageos/hardware/TouchscreenGesture.java
index d9463a37..2af933f4 100644
--- a/sdk/src/java/lineageos/hardware/TouchscreenGesture.java
+++ b/sdk/src/java/lineageos/hardware/TouchscreenGesture.java
@@ -15,7 +15,7 @@
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
import android.os.Parcel;
import android.os.Parcelable;
diff --git a/sdk/src/java/lineageos/hardware/LineageHardwareManager.java b/sdk/src/java/lineageos/hardware/LineageHardwareManager.java
index 279d07fe..58696bee 100644
--- a/sdk/src/java/lineageos/hardware/LineageHardwareManager.java
+++ b/sdk/src/java/lineageos/hardware/LineageHardwareManager.java
@@ -14,7 +14,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
import android.content.Context;
import android.os.IBinder;
@@ -25,8 +25,8 @@ import android.util.Range;
import com.android.internal.annotations.VisibleForTesting;
-import cyanogenmod.app.CMContextConstants;
-import cyanogenmod.hardware.HSIC;
+import lineageos.app.LineageContextConstants;
+import lineageos.hardware.HSIC;
import java.io.UnsupportedEncodingException;
import java.lang.IllegalArgumentException;
@@ -36,17 +36,17 @@ import java.util.Arrays;
import java.util.List;
/**
* Manages access to CyanogenMod hardware extensions
*
* <p>
* This manager requires the HARDWARE_ABSTRACTION_ACCESS permission.
* <p>
* To get the instance of this class, utilize CMHardwareManager#getInstance(Context context)
*/
-public final class CMHardwareManager {
- private static final String TAG = "CMHardwareManager";
+public final class LineageHardwareManager {
+ private static final String TAG = "LineageHardwareManager";
- private static ICMHardwareService sService;
+ private static ILineageHardwareService sService;
private Context mContext;
@@ -113,7 +113,7 @@ public final class CMHardwareManager {
/**
* Double-tap the touch panel to wake up the device
*
* @deprecated This functionality is replaced by AOSP's implementation as of CM 13.0.
*/
@Deprecated
@VisibleForTesting
@@ -190,12 +190,12 @@ public final class CMHardwareManager {
FEATURE_THERMAL_MONITOR
);
- private static CMHardwareManager sCMHardwareManagerInstance;
+ private static LineageHardwareManager sLineageHardwareManagerInstance;
/**
* @hide to prevent subclassing from outside of the framework
*/
- private CMHardwareManager(Context context) {
+ private LineageHardwareManager(Context context) {
Context appContext = context.getApplicationContext();
if (appContext != null) {
mContext = appContext;
@@ -205,33 +205,33 @@ public final class CMHardwareManager {
sService = getService();
if (context.getPackageManager().hasSystemFeature(
- CMContextConstants.Features.HARDWARE_ABSTRACTION) && !checkService()) {
- Log.wtf(TAG, "Unable to get CMHardwareService. The service either" +
+ LineageContextConstants.Features.HARDWARE_ABSTRACTION) && !checkService()) {
+ Log.wtf(TAG, "Unable to get LineageHardwareService. The service either" +
" crashed, was not started, or the interface has been called to early in" +
" SystemServer init");
}
}
/**
- * Get or create an instance of the {@link cyanogenmod.hardware.CMHardwareManager}
+ * Get or create an instance of the {@link lineageos.hardware.LineageHardwareManager}
* @param context
- * @return {@link CMHardwareManager}
+ * @return {@link LineageHardwareManager}
*/
- public static CMHardwareManager getInstance(Context context) {
- if (sCMHardwareManagerInstance == null) {
- sCMHardwareManagerInstance = new CMHardwareManager(context);
+ public static LineageHardwareManager getInstance(Context context) {
+ if (sLineageHardwareManagerInstance == null) {
+ sLineageHardwareManagerInstance = new LineageHardwareManager(context);
}
- return sCMHardwareManagerInstance;
+ return sLineageHardwareManagerInstance;
}
/** @hide */
- public static ICMHardwareService getService() {
+ public static ILineageHardwareService getService() {
if (sService != null) {
return sService;
}
- IBinder b = ServiceManager.getService(CMContextConstants.CM_HARDWARE_SERVICE);
+ IBinder b = ServiceManager.getService(LineageContextConstants.LINEAGE_HARDWARE_SERVICE);
if (b != null) {
- sService = ICMHardwareService.Stub.asInterface(b);
+ sService = ILineageHardwareService.Stub.asInterface(b);
return sService;
}
return null;
@@ -251,9 +251,9 @@ public final class CMHardwareManager {
}
/**
* Determine if a CM Hardware feature is supported on this device
*
* @param feature The CM Hardware feature to query
*
* @return true if the feature is supported, false otherwise.
*/
@@ -286,7 +286,7 @@ public final class CMHardwareManager {
*
* Only used for features which have simple enable/disable controls.
*
* @param feature the CM Hardware feature to query
*
* @return true if the feature is enabled, false otherwise.
*/
@@ -309,7 +309,7 @@ public final class CMHardwareManager {
*
* Only used for features which have simple enable/disable controls.
*
* @param feature the CM Hardware feature to set
* @param enable true to enable, false to disale
*
* @return true if the feature is enabled, false otherwise.
@@ -1003,14 +1003,14 @@ public final class CMHardwareManager {
*/
private boolean checkService() {
if (sService == null) {
- Log.w(TAG, "not connected to CMHardwareManagerService");
+ Log.w(TAG, "not connected to LineageHardwareManagerService");
return false;
}
return true;
}
/**
- * @return current thermal {@link cyanogenmod.hardware.ThermalListenerCallback.State}
+ * @return current thermal {@link lineageos.hardware.ThermalListenerCallback.State}
*/
public int getThermalState() {
try {
@@ -36,17 +36,17 @@ import java.util.Arrays;
import java.util.List;
/**
- * Manages access to CyanogenMod hardware extensions
+ * Manages access to LineageOS hardware extensions
*
* <p>
@@ -36,17 +36,17 @@ import java.util.Arrays;
* This manager requires the HARDWARE_ABSTRACTION_ACCESS permission.
* <p>
- * To get the instance of this class, utilize CMHardwareManager#getInstance(Context context)
+ * To get the instance of this class, utilize LineageHardwareManager#getInstance(Context context)
*/
@@ -113,7 +113,7 @@ public final class CMHardwareManager {
* Double-tap the touch panel to wake up the device
*
- * @deprecated This functionality is replaced by AOSP's implementation as of CM 13.0.
+ * @deprecated This functionality is replaced by AOSP's implementation as of Lineage 13.0.
*/
@@ -251,9 +251,9 @@ public final class CMHardwareManager {
}
/**
- * Determine if a CM Hardware feature is supported on this device
+ * Determine if a Lineage Hardware feature is supported on this device
*
@@ -251,9 +251,9 @@ public final class CMHardwareManager {
*
- * @param feature The CM Hardware feature to query
+ * @param feature The Lineage Hardware feature to query
*
* @return true if the feature is supported, false otherwise.
@@ -286,7 +286,7 @@ public final class CMHardwareManager {
* Only used for features which have simple enable/disable controls.
*
- * @param feature the CM Hardware feature to query
+ * @param feature the Lineage Hardware feature to query
*
* @return true if the feature is enabled, false otherwise.
@@ -309,7 +309,7 @@ public final class CMHardwareManager {
* Only used for features which have simple enable/disable controls.
*
- * @param feature the CM Hardware feature to set
+ * @param feature the Lineage Hardware feature to set
* @param enable true to enable, false to disale
*
diff --git a/sdk/src/java/lineageos/hardware/LiveDisplayManager.java b/sdk/src/java/lineageos/hardware/LiveDisplayManager.java
index cfe904f8..2ad650ce 100644
--- a/sdk/src/java/lineageos/hardware/LiveDisplayManager.java
+++ b/sdk/src/java/lineageos/hardware/LiveDisplayManager.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package cyanogenmod.hardware;
+package lineageos.hardware;
import android.content.Context;
import android.os.IBinder;
@@ -26,7 +26,7 @@ import java.util.Arrays;
import java.util.Collections;
import java.util.List;
-import cyanogenmod.app.CMContextConstants;
+import lineageos.app.LineageContextConstants;
/**
* LiveDisplay is an advanced set of features for improving
@@ -34,7 +34,7 @@ import cyanogenmod.app.CMContextConstants;
*
* The backend service is constructed with a set of LiveDisplayFeatures
* which provide capabilities such as outdoor mode, night mode,
* and calibration. It interacts with CMHardwareService to relay
* changes down to the lower layers.
*
* Multiple adaptive modes are supported, and various hardware
@@ -151,7 +151,7 @@ public class LiveDisplayManager {
sService = getService();
if (!context.getPackageManager().hasSystemFeature(
- CMContextConstants.Features.LIVEDISPLAY) || !checkService()) {
+ LineageContextConstants.Features.LIVEDISPLAY) || !checkService()) {
Log.wtf(TAG, "Unable to get LiveDisplayService. The service either" +
" crashed, was not started, or the interface has been called to early in" +
" SystemServer init");
@@ -168,7 +168,7 @@ public class LiveDisplayManager {
}
/**
- * Get or create an instance of the {@link cyanogenmod.hardware.LiveDisplayManager}
+ * Get or create an instance of the {@link lineageos.hardware.LiveDisplayManager}
* @param context
* @return {@link LiveDisplayManager}
*/
@@ -184,7 +184,7 @@ public class LiveDisplayManager {
if (sService != null) {
return sService;
}
- IBinder b = ServiceManager.getService(CMContextConstants.CM_LIVEDISPLAY_SERVICE);
+ IBinder b = ServiceManager.getService(LineageContextConstants.LINEAGE_LIVEDISPLAY_SERVICE);
if (b != null) {
sService = ILiveDisplayService.Stub.asInterface(b);
return sService;
@@ -197,7 +197,7 @@ public class LiveDisplayManager {
*/
private boolean checkService() {
if (sService == null) {
- Log.w(TAG, "not connected to CMHardwareManagerService");
+ Log.w(TAG, "not connected to LineageHardwareManagerService");
return false;
}
return true;
@@ -34,7 +34,7 @@ import cyanogenmod.app.CMContextConstants;
* The backend service is constructed with a set of LiveDisplayFeatures
* which provide capabilities such as outdoor mode, night mode,
- * and calibration. It interacts with CMHardwareService to relay
+ * and calibration. It interacts with LineageHardwareService to relay
* changes down to the lower layers.
*